<?php

namespace Drupal\ds_static_node_reference\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\ds\Form\FieldFormBase;

/**
 * Configure static node-reference fields.
 */
class StaticNodeReferenceFieldForm extends FieldFormBase {
  /**
   * The type of the display suite field.
   */
  const TYPE = 'static_node_reference';

  /**
   * {@inheritdoc}
   */
  public function getType() {
    return StaticNodeReferenceFieldForm::TYPE;
  }

  /**
   * {@inheritdoc}
   */
  public function getTypeLabel() {
    return 'Static node reference field';
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'ds_static_node_reference_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $field_key = '') {
    $form = parent::buildForm($form, $form_state, $field_key);
    // Retrieve the Node that was previously selected, if any.
    if (!empty($this->field['properties']['static_node'])) {
      $selected_node = $this->entityTypeManager->getStorage('node')->load($this->field['properties']['static_node']);
    }
    // Use the entity_autocomplete field type from Core.
    $form['static_node'] = [
      '#type' => 'entity_autocomplete',
      '#target_type' => 'node',
      '#title' => $this->t('Node'),
      '#description' => $this->t('Choose a node to be rendered in this field.'),
      '#default_value' => isset($selected_node) ? $selected_node : NULL,
      '#required' => TRUE,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function getProperties(FormStateInterface $form_state) {
    return [
      'static_node' => $form_state->getValue('static_node'),
    ];
  }

}
