<?php

namespace Drupal\ds_static_node_reference\Plugin\DsField;

use Drupal\Core\Entity\EntityDisplayRepositoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\ds\Plugin\DsField\Entity;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Generated static node-reference field.
 *
 * @DsField(
 *   id = "static_node_reference_field",
 *   deriver = "Drupal\ds_static_node_reference\Plugin\Derivative\StaticNodeReferenceField",
 *   provider = "node"
 * )
 */
class StaticNodeReferenceField extends Entity implements ContainerFactoryPluginInterface {
  protected $staticNodeID;
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
        $configuration,
        $plugin_id,
        $plugin_definition,
        $container->get('entity_type.manager'),
        $container->get('entity_display.repository')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function __construct($configuration,
  $plugin_id,
  $plugin_definition,
                              EntityTypeManagerInterface $entity_type_manager,
                              EntityDisplayRepositoryInterface $entity_display_repository) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $entity_display_repository);
    $this->entityTypeManager = $entity_type_manager;
    $this->staticNodeID = $configuration['field']['properties']['static_node'];
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $static_node = $this->entityTypeManager->getStorage('node')->load($this->staticNodeID);
    return !empty($static_node) ? $this->entityTypeManager->getViewBuilder('node')->view($static_node, $this->getEntityViewMode()) : NULL;
  }

  /**
   * Gets the wanted entity.
   */
  public function linkedEntity() {
    return 'node';
  }

  /**
   * {@inheritdoc}
   */
  public function formatters() {

    $formatters = array(
      'entity_reference_entity_view' => t('Rendered entity'),
    );

    return $formatters;
  }

}
